@@ -381,30 +381,55 @@ class fileviewer(object):
                                      else ('L+', 'L-', 'R-', 'R+')
         try:     
             val = int(np.sum([data.hist[h].data for h in hist]))
-            data_sw['Total Counts Sample'] = f'{val:,}'.replace(',', ' ')
+            val, unit_val = num_prefix(val)
+            # ~ data_sw['Total Counts Sample'] = f'{val:,}'.replace(',', ' ')
+            data_sw['Total Counts Sample'] = "%.3g%s" % (val, unit_val)
             key_order_sw.append('Total Counts Sample')
         except (AttributeError, KeyError):
             pass
         
         try: 
             val = int(np.sum([data.hist[h].data for h in hist])/data.duration)
-            data_sw['Rate Sample'] =  f'{val:,} (1/s)'.replace(',', ' ')
-            key_order_sw.append('Rate Sample')
+            val, unit_val = num_prefix(val)
+            data_sw['Total Rate Sample'] =  "%.3g%s (cps)" % (val, unit_val)
+            key_order_sw.append('Total Rate Sample')
         except (AttributeError, KeyError):
             pass
         
+        try: 
+            tag_F = 'F' if data.area == 'BNMR' else 'L'
+            tag_B = 'B' if data.area == 'BNMR' else 'R'
+    
+            F = np.sum([data.hist[h].data for h in hist if tag_F in h])/data.duration
+            B = np.sum([data.hist[h].data for h in hist if tag_B in h])/data.duration
+            
+            F, unit_F = num_prefix(F)
+            B, unit_B = num_prefix(B)
+            
+            data_sw['Rate %s/%s' % (tag_F, tag_B)] = \
+                    '%.3g%s / %.3g%s (cps) [ratio: %.2f]' % (F, unit_F, B, unit_B, F/B)
+            key_order_sw.append('Rate %s/%s' % (tag_F, tag_B))
+        except (AttributeError, KeyError):
+            pass
+        
+        key_order_sw.append('')
+        
         hist = ('F+', 'F-', 'B-', 'B+')    
         try: 
             val = int(np.sum([data.hist['NBM'+h].data for h in hist]))
-            data_sw['Total Counts NBM'] = f'{val:,}'.replace(',', ' ')
+            val, unit_val = num_prefix(val)
+            # ~ data_sw['Total Counts NBM'] = f'{val:,}'.replace(',', ' ')
+            data_sw['Total Counts NBM'] = "%.3g%s" % (val, unit_val)
             key_order_sw.append('Total Counts NBM')
         except (AttributeError, KeyError):
             pass
         
         try: 
             val = int(np.sum([data.hist['NBM'+h].data for h in hist])/data.duration)
-            data_sw['Rate NBM'] = f'{val:,} (1/s)'.replace(',', ' ')
-            key_order_sw.append('Rate NBM')
+            val, unit_val = num_prefix(val)
+            data_sw['Total Rate NBM'] = "%.3g%s (cps)" % (val, unit_val)
+            # ~ data_sw['Total Rate NBM'] = f'{val:,} (1/s)'.replace(',', ' ')
+            key_order_sw.append('Total Rate NBM')
         except (AttributeError, KeyError):
             pass
             
@@ -451,6 +476,30 @@ class fileviewer(object):
         except AttributeError:
             pass
         
+        try:
+            data_se["Doppler Tube CH0"] = "%.3f +/- %.3f V" % \
+                    (np.around(data.epics.dopplertube_ch0.mean, 3), 
+                     np.around(data.epics.dopplertube_ch0.std, 3))
+            key_order_se.append('Doppler Tube CH0')
+        except AttributeError:
+            pass
+        
+        try:
+            data_se["Doppler Tube CH1"] = "%.3f +/- %.3f V" % \
+                    (np.around(data.epics.dopplertube_ch1.mean, 3), 
+                     np.around(data.epics.dopplertube_ch1.std, 3))
+            key_order_se.append('Doppler Tube CH1')
+        except AttributeError:
+            pass
+        
+        try:
+            data_se["Doppler Tube CH2"] = "%.3f +/- %.3f V" % \
+                    (np.around(data.epics.dopplertube_ch2.mean, 3), 
+                     np.around(data.epics.dopplertube_ch2.std, 3))
+            key_order_se.append('Doppler Tube CH2')
+        except AttributeError:
+            pass
+        
         # get data: beam energy
         try: 
             init_bias = data.epics.target_bias.mean
@@ -484,7 +533,7 @@ class fileviewer(object):
         # laser stuff
         try: 
             val = data.epics.las_pwr
-            data_se['Laser Power'] = "%.3f +/- %.3f A" % (val.mean, val.std)
+            data_se['Laser Power'] = "%.3f +/- %.3f V" % (val.mean, val.std)
             key_order_se.append('Laser Power')
         except AttributeError:
             pass
@@ -897,7 +946,7 @@ class fileviewer(object):
                 unit = str(ppg.units).title()
                 data_ne['Scan start'] = '%d %s' % (start, unit)
                 key_order_ne.append('Scan start')
-            except AttributeError:
+            except (AttributeError, KeyError):
                 pass
             
             try:    
@@ -906,7 +955,7 @@ class fileviewer(object):
                 unit = str(ppg.units).title()
                 data_ne['Scan stop'] = '%d %s' % (stop, unit)
                 key_order_ne.append('Scan stop')
-            except AttributeError:
+            except (AttributeError, KeyError):
                 pass
             
             try:
@@ -915,7 +964,7 @@ class fileviewer(object):
                 unit = str(ppg.units).title()
                 data_ne['Scan gap'] = '%d %s' % (incr, unit)
                 key_order_ne.append('Scan gap')
-            except AttributeError:
+            except (AttributeError, KeyError):
                 pass
             
             try:
@@ -1400,4 +1449,9 @@ class fileviewer(object):
                 self.bfit.plt.active['periodic'] = 0
             
 # =========================================================================== #
-
+def num_prefix(val):
+    if val > 1e9: return (val/1e9, 'G')
+    if val > 1e6: return (val/1e6, 'M')
+    if val > 1e3: return (val/1e3, 'k')
+    
+    return (val, '')
